@@ -257,22 +257,6 @@ class RootwrapClientChannel(_ClientChannel):
         Uses sudo/rootwrap to gain privileges.
         """
 
-        # We need to be able to reconstruct the context object in the new
-        # python process we'll get after rootwrap/sudo.  This means we
-        # need to construct the context object and store it somewhere
-        # globally accessible, and then use that python name to find it
-        # again in the new python interpreter.  Yes, it's all a bit
-        # clumsy, and none of it is required when using the fork-based
-        # alternative above.
-        # These asserts here are just attempts to catch errors earlier.
-        # TODO(gus): Consider replacing with setuptools entry_points.
-        assert context.pypath is not None, (
-            'RootwrapClientChannel requires priv_context '
-            'pypath to be specified')
-        assert importutils.import_class(context.pypath) is context, (
-            'RootwrapClientChannel requires priv_context pypath '
-            'for context object')
-
         listen_sock = socket.socket(socket.AF_UNIX)
 
         # Note we listen() on the unprivileged side, and connect to it
@@ -290,9 +274,7 @@ class RootwrapClientChannel(_ClientChannel):
             listen_sock.bind(sockpath)
             listen_sock.listen(1)
 
-            cmd = shlex.split(context.conf.helper_command) + [
-                '--privsep_context', context.pypath,
-                '--privsep_sock_path', sockpath]
+            cmd = self._helper_command(context, sockpath)
             LOG.info(_LI('Running privsep helper: %s'), cmd)
             proc = subprocess.Popen(cmd, shell=False, stderr=_fd_logger())
             if proc.wait() != 0:
@@ -317,6 +299,50 @@ class RootwrapClientChannel(_ClientChannel):
 
         super(RootwrapClientChannel, self).__init__(sock)
 
+    @staticmethod
+    def _helper_command(context, sockpath):
+        # We need to be able to reconstruct the context object in the new
+        # python process we'll get after rootwrap/sudo.  This means we
+        # need to construct the context object and store it somewhere
+        # globally accessible, and then use that python name to find it
+        # again in the new python interpreter.  Yes, it's all a bit
+        # clumsy, and none of it is required when using the fork-based
+        # alternative above.
+        # These asserts here are just attempts to catch errors earlier.
+        # TODO(gus): Consider replacing with setuptools entry_points.
+        assert context.pypath is not None, (
+            'RootwrapClientChannel requires priv_context '
+            'pypath to be specified')
+        assert importutils.import_class(context.pypath) is context, (
+            'RootwrapClientChannel requires priv_context pypath '
+            'for context object')
+
+        # Note order is important here.  Deployments will (hopefully)
+        # have the exact arguments in sudoers/rootwrap configs and
+        # reordering args will break configs!
+
+        if context.conf.helper_command:
+            cmd = shlex.split(context.conf.helper_command)
+        else:
+            cmd = ['sudo', 'privsep-helper']
+
+            try:
+                for cfg_file in cfg.CONF.config_file:
+                    cmd.extend(['--config-file', cfg_file])
+            except cfg.NoSuchOptError:
+                pass
+
+            try:
+                cmd.extend(['--config-dir', cfg.CONF.config_dir])
+            except cfg.NoSuchOptError:
+                pass
+
+        cmd.extend(
+            ['--privsep_context', context.pypath,
+             '--privsep_sock_path', sockpath])
+
+        return cmd
+
 
 class Daemon(object):
     """NB: This doesn't fork() - do that yourself before calling run()"""
